@@ -1,3 +1,6 @@
+import re
+from typing import Dict, Any
+
 from ulid import ULID
 
 
@@ -6,6 +9,11 @@ from ..common import BaseClass, PrimitiveBase
 
 class ID(PrimitiveBase, ULID):
     coerce = True
+    regex = re.compile(r"^[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$")
+
+    @classmethod
+    def __modify_schema__(cls, field_schema: Dict[str, Any]) -> None:
+        field_schema.update(type="string", format="ulid", pattern=cls.regex.pattern)
 
     def __repr__(self):
         return f"{self.__class__.__name__}('{str(self)}')"
